@@ -7,6 +7,13 @@ class SchemaType(Enum):
     AVRO = 'AVRO'
     GREAT_EXPECTATIONS = 'GREAT_EXPECTATIONS'
 
+
+class FileType(Enum):
+    JSON = 'JSON'
+    AVRO = 'AVRO'
+    CSV = 'CSV'
+
+
 class Schema:
     """
     Class used to aid in the use of schema objects
@@ -19,4 +26,7 @@ class Schema:
         return self.__dict__
 
     def get_schema(self):
-        return json.loads(self.schema)
\ No newline at end of file
+        return json.loads(self.schema)
+
+    def get_schema_type(self):
+        return SchemaType[self.schemaType]
